Forum Discussion
HKim27
Occasional Contributor
7 years agoPAC Arria 10 GX, aoc compilation error
Hi, all I installed acceleration stack, followed guide to install bsp and setup environment variables. "aocl diagnose" detects device well, and pre-compiled aocx examples run well. But when I try ...
HKim27
Occasional Contributor
7 years agoBut what I compiled is just OpenCL kernel:
__kernel void vector_add(__global const float *x,
__global const float *y,
__global float *restrict z)
{
// get index of the work item
int index = get_global_id(0);
// add the vector elements
z[index] = x[index] + y[index];
}So there is no RTL design